use serde::{Deserialize, Serialize};

#[derive(Deserialize, Serialize, Debug, Clone)]
pub struct TinkoffApiKey{
    pub name: String,
    pub key: String,
    pub time: i64,
}
